@@ -933,16 +933,19 @@ class TestResultFileBinary:
         stream = BytesIO()
         _run_negated_alias(simple_alias, "binary", stream)
 
-    def _get_bouncing_ball_dummy(self):
+    def _get_bouncing_ball_dummy(self, fmu_type = 'me2'):
         """ Returns an instance of Dummy_FMUModelME2 using bouncingBall. """
-        return Dummy_FMUModelME2([], os.path.join(file_path, "files", "FMUs", "XML", "ME2.0", "bouncingBall.fmu"), _connect_dll=False)
+        if fmu_type == 'me2':
+            return Dummy_FMUModelME2([], os.path.join(file_path, "files", "FMUs", "XML", "ME2.0", "bouncingBall.fmu"), _connect_dll=False)
+        elif fmu_type == 'me1':
+            return Dummy_FMUModelME1([], os.path.join(file_path, "files", "FMUs", "XML", "ME1.0", "bouncingBall.fmu"), _connect_dll=False)
 
     @testattr(stddist = True)
     def test_exception_simulation_start(self):
         """ Verify exception is raised if simulation_start is invoked without arguments. """
         model = self._get_bouncing_ball_dummy()
         opts = model.simulate_options()
-        opts["logging"] = True
+        opts["dynamic_diagnostics"] = True
         model.setup_experiment()
         model.initialize()
 
@@ -982,7 +985,7 @@ class TestResultFileBinary:
         # values used as diagnostics data at each point
         diag_data = np.array([val[0] for val in diagnostics_vars.values()], dtype=float)
 
-        opts["logging"] = True
+        opts["dynamic_diagnostics"] = True
         opts["result_file_name"] = result_file_name
 
         # Generate data
@@ -1037,12 +1040,132 @@ class TestResultFileBinary:
         test_file_stream = open('myfilestream.txt', 'wb')
         self._get_diagnostics_cancelled_sim(test_file_stream)
 
+
+    @testattr(stddist = True)
+    def test_debug_file_not_generated_when_dynamic_diagnostics_is_true(self):
+        """ Verify that the debug file is not created when option dynamic_diagnostics is true. """
+        model = self._get_bouncing_ball_dummy()
+        opts = model.simulate_options()
+        opts["dynamic_diagnostics"] = True
+        potential_debug_file = "{}_debug.txt".format(model.get_identifier())
+        if os.path.isfile(potential_debug_file):
+            os.remove(potential_debug_file)
+
+        model.simulate(options = opts)
+        nose.tools.assert_false(os.path.isfile(potential_debug_file),
+                                "Test failed, file {} exists after simulation".format(potential_debug_file))
+
+    @testattr(stddist = True)
+    def test_exception_dynamic_diagnostics_and_non_binary_result_handling(self):
+        """ Verify that exception is raised if dynamic diagnostics is True and result_handling is not binary. """
+        model = self._get_bouncing_ball_dummy()
+        opts = model.simulate_options()
+        opts["dynamic_diagnostics"] = True
+        opts["result_handling"] = "csv" # set to anything except "binary"
+
+        err_msg = "In order to simulate with 'dynamic\_diagnostics', "
+        err_msg += "the 'result_handler' must be an instance of ResultHandlerBinaryFile."
+        with nose.tools.assert_raises_regex(fmi.InvalidOptionException, err_msg):
+            model.simulate(options = opts)
+
+    @testattr(stddist = True)
+    def test_exception_dynamic_diagnostics_and_non_binary_result_handling1(self):
+        """ Verify that exception is raised if dynamic diagnostics is True and result_handling is custom and invalid class. """
+        model = self._get_bouncing_ball_dummy()
+        opts = model.simulate_options()
+        opts["dynamic_diagnostics"] = True
+        opts["result_handling"] = "custom" # set to anything except "binary"
+
+        class Foo:
+            pass
+        opts["result_handler"] = Foo()
+        err_msg = "In order to simulate with 'dynamic\_diagnostics', "
+        err_msg += "the 'result_handler' must be an instance of ResultHandlerBinaryFile."
+        with nose.tools.assert_raises_regex(fmi.InvalidOptionException, err_msg):
+            model.simulate(options = opts)
+
+    @testattr(stddist = True)
+    def test_exception_dynamic_diagnostics_and_non_binary_result_handling2(self):
+        """ Verify that exception is raised if dynamic diagnostics is True and result_handling is custom and valid class. """
+        model = self._get_bouncing_ball_dummy()
+        opts = model.simulate_options()
+        opts["dynamic_diagnostics"] = True
+        opts["result_handling"] = "custom" # set to anything except "binary"
+
+        opts["result_handler"] = ResultHandlerBinaryFile(model)
+        no_error = False
+        exception_msg = ""
+        try:
+            model.simulate(options = opts)
+            no_error = True
+        except Exception as e:
+            no_error = False
+            exception_msg = str(e)
+            raise e
+        # In case error did not stop the test run
+        nose.tools.assert_true(no_error, "Error occurred: {}".format(exception_msg))
+
+    def _test_no_debug_file(self, fmu_type):
+        model = self._get_bouncing_ball_dummy(fmu_type=fmu_type)
+        opts = model.simulate_options()
+        opts["logging"] = True
+
+        expected_debug_file = "{}_debug.txt".format(model.get_identifier())
+        if os.path.isfile(expected_debug_file):
+            os.remove(expected_debug_file)
+
+        model.simulate(options = opts)
+
+        nose.tools.assert_false(os.path.isfile(expected_debug_file),
+                                "Test failed, found file '{}'".format(expected_debug_file))
+
+    @testattr(stddist = True)
+    def test_debug_file_not_generated_me1(self):
+        """ Verify that the debug file is not generated by enabling logging (ME1). """
+        self._test_no_debug_file(fmu_type = 'me1')
+
+    @testattr(stddist = True)
+    def test_debug_file_not_generated_me2(self):
+        """ Verify that the debug file is not generated by enabling logging (ME2). """
+        self._test_no_debug_file(fmu_type = 'me2')
+
+    def _test_debug_file_opening(self, fmu_type):
+        model = self._get_bouncing_ball_dummy(fmu_type=fmu_type)
+        opts = model.simulate_options()
+        opts["logging"] = True
+        opts["result_handling"] = "csv" # set to anything except 'binary'
+
+        expected_debug_file = "{}_debug.txt".format(model.get_identifier())
+        if os.path.isfile(expected_debug_file):
+            os.remove(expected_debug_file)
+
+        test_str = 'thislinewillberemoved'
+        # Now add test_str to file, simulate, and verify that test_str is gone
+        with open(expected_debug_file, 'w') as f:
+            f.write(test_str)
+        model.simulate(options = opts)
+
+        # Verify
+        with open(expected_debug_file, 'r') as f:
+            l = f.readline()
+        nose.tools.assert_false(test_str in l, "Test failed, found '{}' in '{}'".format(test_str, l))
+
+    @testattr(stddist = True)
+    def test_debug_file_opened_in_write_mode_me1(self):
+        """ Verify that the debug file is opened in write mode if it already did exist (ME1). """
+        self._test_debug_file_opening(fmu_type = 'me1')
+
+    @testattr(stddist = True)
+    def test_debug_file_opened_in_write_mode_me2(self):
+        """ Verify that the debug file is opened in write mode if it already did exist (ME2). """
+        self._test_debug_file_opening(fmu_type = 'me1')
+
     @testattr(stddist = True)
     def test_diagnostics_numerical_values(self):
         """ Verify that we get the expected values for some diagnostics. """
         model = self._get_bouncing_ball_dummy()
         opts = model.simulate_options()
-        opts["logging"] = True
+        opts["dynamic_diagnostics"] = True
         opts["ncp"] = 250
         res = model.simulate(options=opts)
         length = len(res['h'])
